|  | Chart Axis Dtype
--- | --- | ---
|  | Numeric types | Naive chrono types
Python Series Type | i32 | i64 | f32 | f64 | DateTime | Date | Time
Numeric types | List[int] | o | o | o | o |  |  |
np.array(dtype=i32) | o | o | o | o |  |  |
List[float] |  |  | o | o |  |  |
np.array(dtype=float) |  |  | o | o |  |  |
Naive chrono types | List[datetime.datetime] |  |  |  |  | o | o | o
List[datetime.date] |  |  |  |  |  | o |
List[datetime.time] |  |  |  |  |  |  | o
ezel.StringDateTime |  |  |  |  |  |  |
ezel.Timestamp |  |  |  |  | o | o | o
ezel.MilliTimestamp |  |  |  |  | o | o | o
ezel.MicroTimestamp |  |  |  |  | o | o | o
ezel.NanoTimestamp |  |  |  |  | o | o | o